// autogenerated by syzkaller (https://github.com/google/syzkaller)

#define _GNU_SOURCE

#include <dirent.h>
#include <endian.h>
#include <errno.h>
#include <fcntl.h>
#include <pthread.h>
#include <sched.h>
#include <setjmp.h>
#include <signal.h>
#include <stdarg.h>
#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/ioctl.h>
#include <sys/mman.h>
#include <sys/mount.h>
#include <sys/prctl.h>
#include <sys/resource.h>
#include <sys/stat.h>
#include <sys/syscall.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <time.h>
#include <unistd.h>

#include <linux/capability.h>
#include <linux/futex.h>
#include <linux/loop.h>

#ifndef __NR_memfd_create
#define __NR_memfd_create 319
#endif

static unsigned long long procid;

static void sleep_ms(uint64_t ms)
{
  usleep(ms * 1000);
}

static uint64_t current_time_ms(void)
{
  struct timespec ts;
  if (clock_gettime(CLOCK_MONOTONIC, &ts))
    exit(1);
  return (uint64_t)ts.tv_sec * 1000 + (uint64_t)ts.tv_nsec / 1000000;
}

static void use_temporary_dir(void)
{
  char tmpdir_template[] = "./syzkaller.XXXXXX";
  char* tmpdir = mkdtemp(tmpdir_template);
  if (!tmpdir)
    exit(1);
  if (chmod(tmpdir, 0777))
    exit(1);
  if (chdir(tmpdir))
    exit(1);
}

static void thread_start(void* (*fn)(void*), void* arg)
{
  pthread_t th;
  pthread_attr_t attr;
  pthread_attr_init(&attr);
  pthread_attr_setstacksize(&attr, 128 << 10);
  int i = 0;
  for (; i < 100; i++) {
    if (pthread_create(&th, &attr, fn, arg) == 0) {
      pthread_attr_destroy(&attr);
      return;
    }
    if (errno == EAGAIN) {
      usleep(50);
      continue;
    }
    break;
  }
  exit(1);
}

typedef struct {
  int state;
} event_t;

static void event_init(event_t* ev)
{
  ev->state = 0;
}

static void event_reset(event_t* ev)
{
  ev->state = 0;
}

static void event_set(event_t* ev)
{
  if (ev->state)
    exit(1);
  __atomic_store_n(&ev->state, 1, __ATOMIC_RELEASE);
  syscall(SYS_futex, &ev->state, FUTEX_WAKE | FUTEX_PRIVATE_FLAG, 1000000);
}

static void event_wait(event_t* ev)
{
  while (!__atomic_load_n(&ev->state, __ATOMIC_ACQUIRE))
    syscall(SYS_futex, &ev->state, FUTEX_WAIT | FUTEX_PRIVATE_FLAG, 0, 0);
}

static int event_isset(event_t* ev)
{
  return __atomic_load_n(&ev->state, __ATOMIC_ACQUIRE);
}

static int event_timedwait(event_t* ev, uint64_t timeout)
{
  uint64_t start = current_time_ms();
  uint64_t now = start;
  for (;;) {
    uint64_t remain = timeout - (now - start);
    struct timespec ts;
    ts.tv_sec = remain / 1000;
    ts.tv_nsec = (remain % 1000) * 1000 * 1000;
    syscall(SYS_futex, &ev->state, FUTEX_WAIT | FUTEX_PRIVATE_FLAG, 0, &ts);
    if (__atomic_load_n(&ev->state, __ATOMIC_ACQUIRE))
      return 1;
    now = current_time_ms();
    if (now - start > timeout)
      return 0;
  }
}

static bool write_file(const char* file, const char* what, ...)
{
  char buf[1024];
  va_list args;
  va_start(args, what);
  vsnprintf(buf, sizeof(buf), what, args);
  va_end(args);
  buf[sizeof(buf) - 1] = 0;
  int len = strlen(buf);
  int fd = open(file, O_WRONLY | O_CLOEXEC);
  if (fd == -1)
    return false;
  if (write(fd, buf, len) != len) {
    int err = errno;
    close(fd);
    errno = err;
    return false;
  }
  close(fd);
  return true;
}

#define MAX_FDS 30

//% This code is derived from puff.{c,h}, found in the zlib development. The
//% original files come with the following copyright notice:

//% Copyright (C) 2002-2013 Mark Adler, all rights reserved
//% version 2.3, 21 Jan 2013
//% This software is provided 'as-is', without any express or implied
//% warranty.  In no event will the author be held liable for any damages
//% arising from the use of this software.
//% Permission is granted to anyone to use this software for any purpose,
//% including commercial applications, and to alter it and redistribute it
//% freely, subject to the following restrictions:
//% 1. The origin of this software must not be misrepresented; you must not
//%    claim that you wrote the original software. If you use this software
//%    in a product, an acknowledgment in the product documentation would be
//%    appreciated but is not required.
//% 2. Altered source versions must be plainly marked as such, and must not be
//%    misrepresented as being the original software.
//% 3. This notice may not be removed or altered from any source distribution.
//% Mark Adler    madler@alumni.caltech.edu

//% BEGIN CODE DERIVED FROM puff.{c,h}

#define MAXBITS 15
#define MAXLCODES 286
#define MAXDCODES 30
#define MAXCODES (MAXLCODES + MAXDCODES)
#define FIXLCODES 288

struct puff_state {
  unsigned char* out;
  unsigned long outlen;
  unsigned long outcnt;
  const unsigned char* in;
  unsigned long inlen;
  unsigned long incnt;
  int bitbuf;
  int bitcnt;
  jmp_buf env;
};
static int puff_bits(struct puff_state* s, int need)
{
  long val = s->bitbuf;
  while (s->bitcnt < need) {
    if (s->incnt == s->inlen)
      longjmp(s->env, 1);
    val |= (long)(s->in[s->incnt++]) << s->bitcnt;
    s->bitcnt += 8;
  }
  s->bitbuf = (int)(val >> need);
  s->bitcnt -= need;
  return (int)(val & ((1L << need) - 1));
}
static int puff_stored(struct puff_state* s)
{
  s->bitbuf = 0;
  s->bitcnt = 0;
  if (s->incnt + 4 > s->inlen)
    return 2;
  unsigned len = s->in[s->incnt++];
  len |= s->in[s->incnt++] << 8;
  if (s->in[s->incnt++] != (~len & 0xff) ||
      s->in[s->incnt++] != ((~len >> 8) & 0xff))
    return -2;
  if (s->incnt + len > s->inlen)
    return 2;
  if (s->outcnt + len > s->outlen)
    return 1;
  for (; len--; s->outcnt++, s->incnt++) {
    if (s->in[s->incnt])
      s->out[s->outcnt] = s->in[s->incnt];
  }
  return 0;
}
struct puff_huffman {
  short* count;
  short* symbol;
};
static int puff_decode(struct puff_state* s, const struct puff_huffman* h)
{
  int first = 0;
  int index = 0;
  int bitbuf = s->bitbuf;
  int left = s->bitcnt;
  int code = first = index = 0;
  int len = 1;
  short* next = h->count + 1;
  while (1) {
    while (left--) {
      code |= bitbuf & 1;
      bitbuf >>= 1;
      int count = *next++;
      if (code - count < first) {
        s->bitbuf = bitbuf;
        s->bitcnt = (s->bitcnt - len) & 7;
        return h->symbol[index + (code - first)];
      }
      index += count;
      first += count;
      first <<= 1;
      code <<= 1;
      len++;
    }
    left = (MAXBITS + 1) - len;
    if (left == 0)
      break;
    if (s->incnt == s->inlen)
      longjmp(s->env, 1);
    bitbuf = s->in[s->incnt++];
    if (left > 8)
      left = 8;
  }
  return -10;
}
static int puff_construct(struct puff_huffman* h, const short* length, int n)
{
  int len;
  for (len = 0; len <= MAXBITS; len++)
    h->count[len] = 0;
  int symbol;
  for (symbol = 0; symbol < n; symbol++)
    (h->count[length[symbol]])++;
  if (h->count[0] == n)
    return 0;
  int left = 1;
  for (len = 1; len <= MAXBITS; len++) {
    left <<= 1;
    left -= h->count[len];
    if (left < 0)
      return left;
  }
  short offs[MAXBITS + 1];
  offs[1] = 0;
  for (len = 1; len < MAXBITS; len++)
    offs[len + 1] = offs[len] + h->count[len];
  for (symbol = 0; symbol < n; symbol++)
    if (length[symbol] != 0)
      h->symbol[offs[length[symbol]]++] = symbol;
  return left;
}
static int puff_codes(struct puff_state* s, const struct puff_huffman* lencode,
                      const struct puff_huffman* distcode)
{
  static const short lens[29] = {3,  4,  5,  6,   7,   8,   9,   10,  11, 13,
                                 15, 17, 19, 23,  27,  31,  35,  43,  51, 59,
                                 67, 83, 99, 115, 131, 163, 195, 227, 258};
  static const short lext[29] = {0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 2, 2,
                                 2, 3, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 0};
  static const short dists[30] = {
      1,    2,    3,    4,    5,    7,    9,    13,    17,    25,
      33,   49,   65,   97,   129,  193,  257,  385,   513,   769,
      1025, 1537, 2049, 3073, 4097, 6145, 8193, 12289, 16385, 24577};
  static const short dext[30] = {0, 0, 0,  0,  1,  1,  2,  2,  3,  3,
                                 4, 4, 5,  5,  6,  6,  7,  7,  8,  8,
                                 9, 9, 10, 10, 11, 11, 12, 12, 13, 13};
  int symbol;
  do {
    symbol = puff_decode(s, lencode);
    if (symbol < 0)
      return symbol;
    if (symbol < 256) {
      if (s->outcnt == s->outlen)
        return 1;
      if (symbol)
        s->out[s->outcnt] = symbol;
      s->outcnt++;
    } else if (symbol > 256) {
      symbol -= 257;
      if (symbol >= 29)
        return -10;
      int len = lens[symbol] + puff_bits(s, lext[symbol]);
      symbol = puff_decode(s, distcode);
      if (symbol < 0)
        return symbol;
      unsigned dist = dists[symbol] + puff_bits(s, dext[symbol]);
      if (dist > s->outcnt)
        return -11;
      if (s->outcnt + len > s->outlen)
        return 1;
      while (len--) {
        if (dist <= s->outcnt && s->out[s->outcnt - dist])
          s->out[s->outcnt] = s->out[s->outcnt - dist];
        s->outcnt++;
      }
    }
  } while (symbol != 256);
  return 0;
}
static int puff_fixed(struct puff_state* s)
{
  static int virgin = 1;
  static short lencnt[MAXBITS + 1], lensym[FIXLCODES];
  static short distcnt[MAXBITS + 1], distsym[MAXDCODES];
  static struct puff_huffman lencode, distcode;
  if (virgin) {
    lencode.count = lencnt;
    lencode.symbol = lensym;
    distcode.count = distcnt;
    distcode.symbol = distsym;
    short lengths[FIXLCODES];
    int symbol;
    for (symbol = 0; symbol < 144; symbol++)
      lengths[symbol] = 8;
    for (; symbol < 256; symbol++)
      lengths[symbol] = 9;
    for (; symbol < 280; symbol++)
      lengths[symbol] = 7;
    for (; symbol < FIXLCODES; symbol++)
      lengths[symbol] = 8;
    puff_construct(&lencode, lengths, FIXLCODES);
    for (symbol = 0; symbol < MAXDCODES; symbol++)
      lengths[symbol] = 5;
    puff_construct(&distcode, lengths, MAXDCODES);
    virgin = 0;
  }
  return puff_codes(s, &lencode, &distcode);
}
static int puff_dynamic(struct puff_state* s)
{
  static const short order[19] = {16, 17, 18, 0, 8,  7, 9,  6, 10, 5,
                                  11, 4,  12, 3, 13, 2, 14, 1, 15};
  int nlen = puff_bits(s, 5) + 257;
  int ndist = puff_bits(s, 5) + 1;
  int ncode = puff_bits(s, 4) + 4;
  if (nlen > MAXLCODES || ndist > MAXDCODES)
    return -3;
  short lengths[MAXCODES];
  int index;
  for (index = 0; index < ncode; index++)
    lengths[order[index]] = puff_bits(s, 3);
  for (; index < 19; index++)
    lengths[order[index]] = 0;
  short lencnt[MAXBITS + 1], lensym[MAXLCODES];
  struct puff_huffman lencode = {lencnt, lensym};
  int err = puff_construct(&lencode, lengths, 19);
  if (err != 0)
    return -4;
  index = 0;
  while (index < nlen + ndist) {
    int symbol;
    int len;
    symbol = puff_decode(s, &lencode);
    if (symbol < 0)
      return symbol;
    if (symbol < 16)
      lengths[index++] = symbol;
    else {
      len = 0;
      if (symbol == 16) {
        if (index == 0)
          return -5;
        len = lengths[index - 1];
        symbol = 3 + puff_bits(s, 2);
      } else if (symbol == 17)
        symbol = 3 + puff_bits(s, 3);
      else
        symbol = 11 + puff_bits(s, 7);
      if (index + symbol > nlen + ndist)
        return -6;
      while (symbol--)
        lengths[index++] = len;
    }
  }
  if (lengths[256] == 0)
    return -9;
  err = puff_construct(&lencode, lengths, nlen);
  if (err && (err < 0 || nlen != lencode.count[0] + lencode.count[1]))
    return -7;
  short distcnt[MAXBITS + 1], distsym[MAXDCODES];
  struct puff_huffman distcode = {distcnt, distsym};
  err = puff_construct(&distcode, lengths + nlen, ndist);
  if (err && (err < 0 || ndist != distcode.count[0] + distcode.count[1]))
    return -8;
  return puff_codes(s, &lencode, &distcode);
}
static int puff(unsigned char* dest, unsigned long* destlen,
                const unsigned char* source, unsigned long sourcelen)
{
  struct puff_state s = {
      .out = dest,
      .outlen = *destlen,
      .outcnt = 0,
      .in = source,
      .inlen = sourcelen,
      .incnt = 0,
      .bitbuf = 0,
      .bitcnt = 0,
  };
  int err;
  if (setjmp(s.env) != 0)
    err = 2;
  else {
    int last;
    do {
      last = puff_bits(&s, 1);
      int type = puff_bits(&s, 2);
      err = type == 0 ? puff_stored(&s)
                      : (type == 1 ? puff_fixed(&s)
                                   : (type == 2 ? puff_dynamic(&s) : -1));
      if (err != 0)
        break;
    } while (!last);
  }
  *destlen = s.outcnt;
  return err;
}

//% END CODE DERIVED FROM puff.{c,h}

#define ZLIB_HEADER_WIDTH 2

static int puff_zlib_to_file(const unsigned char* source,
                             unsigned long sourcelen, int dest_fd)
{
  if (sourcelen < ZLIB_HEADER_WIDTH)
    return 0;
  source += ZLIB_HEADER_WIDTH;
  sourcelen -= ZLIB_HEADER_WIDTH;
  const unsigned long max_destlen = 132 << 20;
  void* ret = mmap(0, max_destlen, PROT_WRITE | PROT_READ,
                   MAP_PRIVATE | MAP_ANON, -1, 0);
  if (ret == MAP_FAILED)
    return -1;
  unsigned char* dest = (unsigned char*)ret;
  unsigned long destlen = max_destlen;
  int err = puff(dest, &destlen, source, sourcelen);
  if (err) {
    munmap(dest, max_destlen);
    errno = -err;
    return -1;
  }
  if (write(dest_fd, dest, destlen) != (ssize_t)destlen) {
    munmap(dest, max_destlen);
    return -1;
  }
  return munmap(dest, destlen);
}

static int setup_loop_device(unsigned char* data, unsigned long size,
                             const char* loopname, int* loopfd_p)
{
  int err = 0, loopfd = -1;
  int memfd = syscall(__NR_memfd_create, "syzkaller", 0);
  if (memfd == -1) {
    err = errno;
    goto error;
  }
  if (puff_zlib_to_file(data, size, memfd)) {
    err = errno;
    goto error_close_memfd;
  }
  loopfd = open(loopname, O_RDWR);
  if (loopfd == -1) {
    err = errno;
    goto error_close_memfd;
  }
  if (ioctl(loopfd, LOOP_SET_FD, memfd)) {
    if (errno != EBUSY) {
      err = errno;
      goto error_close_loop;
    }
    ioctl(loopfd, LOOP_CLR_FD, 0);
    usleep(1000);
    if (ioctl(loopfd, LOOP_SET_FD, memfd)) {
      err = errno;
      goto error_close_loop;
    }
  }
  close(memfd);
  *loopfd_p = loopfd;
  return 0;

error_close_loop:
  close(loopfd);
error_close_memfd:
  close(memfd);
error:
  errno = err;
  return -1;
}

static long syz_mount_image(volatile long fsarg, volatile long dir,
                            volatile long flags, volatile long optsarg,
                            volatile long change_dir,
                            volatile unsigned long size, volatile long image)
{
  unsigned char* data = (unsigned char*)image;
  int res = -1, err = 0, loopfd = -1, need_loop_device = !!size;
  char* mount_opts = (char*)optsarg;
  char* target = (char*)dir;
  char* fs = (char*)fsarg;
  char* source = NULL;
  char loopname[64];
  if (need_loop_device) {
    memset(loopname, 0, sizeof(loopname));
    snprintf(loopname, sizeof(loopname), "/dev/loop%llu", procid);
    if (setup_loop_device(data, size, loopname, &loopfd) == -1)
      return -1;
    source = loopname;
  }
  mkdir(target, 0777);
  char opts[256];
  memset(opts, 0, sizeof(opts));
  if (strlen(mount_opts) > (sizeof(opts) - 32)) {
  }
  strncpy(opts, mount_opts, sizeof(opts) - 32);
  if (strcmp(fs, "iso9660") == 0) {
    flags |= MS_RDONLY;
  } else if (strncmp(fs, "ext", 3) == 0) {
    bool has_remount_ro = false;
    char* remount_ro_start = strstr(opts, "errors=remount-ro");
    if (remount_ro_start != NULL) {
      char after = *(remount_ro_start + strlen("errors=remount-ro"));
      char before = remount_ro_start == opts ? '\0' : *(remount_ro_start - 1);
      has_remount_ro = ((before == '\0' || before == ',') &&
                        (after == '\0' || after == ','));
    }
    if (strstr(opts, "errors=panic") || !has_remount_ro)
      strcat(opts, ",errors=continue");
  } else if (strcmp(fs, "xfs") == 0) {
    strcat(opts, ",nouuid");
  }
  res = mount(source, target, fs, flags, opts);
  if (res == -1) {
    err = errno;
    goto error_clear_loop;
  }
  res = open(target, O_RDONLY | O_DIRECTORY);
  if (res == -1) {
    err = errno;
    goto error_clear_loop;
  }
  if (change_dir) {
    res = chdir(target);
    if (res == -1) {
      err = errno;
    }
  }

error_clear_loop:
  if (need_loop_device) {
    ioctl(loopfd, LOOP_CLR_FD, 0);
    close(loopfd);
  }
  errno = err;
  return res;
}

static void mount_cgroups(const char* dir, const char** controllers, int count)
{
  if (mkdir(dir, 0777)) {
    return;
  }
  char enabled[128] = {0};
  int i = 0;
  for (; i < count; i++) {
    if (mount("none", dir, "cgroup", 0, controllers[i])) {
      continue;
    }
    umount(dir);
    strcat(enabled, ",");
    strcat(enabled, controllers[i]);
  }
  if (enabled[0] == 0) {
    if (rmdir(dir) && errno != EBUSY)
      exit(1);
    return;
  }
  if (mount("none", dir, "cgroup", 0, enabled + 1)) {
    if (rmdir(dir) && errno != EBUSY)
      exit(1);
  }
  if (chmod(dir, 0777)) {
  }
}

static void mount_cgroups2(const char** controllers, int count)
{
  if (mkdir("/syzcgroup/unified", 0777)) {
    return;
  }
  if (mount("none", "/syzcgroup/unified", "cgroup2", 0, NULL)) {
    if (rmdir("/syzcgroup/unified") && errno != EBUSY)
      exit(1);
    return;
  }
  if (chmod("/syzcgroup/unified", 0777)) {
  }
  int control = open("/syzcgroup/unified/cgroup.subtree_control", O_WRONLY);
  if (control == -1)
    return;
  int i;
  for (i = 0; i < count; i++)
    if (write(control, controllers[i], strlen(controllers[i])) < 0) {
    }
  close(control);
}

static void setup_cgroups()
{
  const char* unified_controllers[] = {"+cpu", "+io", "+pids"};
  const char* net_controllers[] = {"net", "net_prio", "devices", "blkio",
                                   "freezer"};
  const char* cpu_controllers[] = {"cpuset", "cpuacct", "hugetlb", "rlimit",
                                   "memory"};
  if (mkdir("/syzcgroup", 0777)) {
    return;
  }
  mount_cgroups2(unified_controllers,
                 sizeof(unified_controllers) / sizeof(unified_controllers[0]));
  mount_cgroups("/syzcgroup/net", net_controllers,
                sizeof(net_controllers) / sizeof(net_controllers[0]));
  mount_cgroups("/syzcgroup/cpu", cpu_controllers,
                sizeof(cpu_controllers) / sizeof(cpu_controllers[0]));
  write_file("/syzcgroup/cpu/cgroup.clone_children", "1");
  write_file("/syzcgroup/cpu/cpuset.memory_pressure_enabled", "1");
}

static void setup_cgroups_loop()
{
  int pid = getpid();
  char file[128];
  char cgroupdir[64];
  snprintf(cgroupdir, sizeof(cgroupdir), "/syzcgroup/unified/syz%llu", procid);
  if (mkdir(cgroupdir, 0777)) {
  }
  snprintf(file, sizeof(file), "%s/pids.max", cgroupdir);
  write_file(file, "32");
  snprintf(file, sizeof(file), "%s/cgroup.procs", cgroupdir);
  write_file(file, "%d", pid);
  snprintf(cgroupdir, sizeof(cgroupdir), "/syzcgroup/cpu/syz%llu", procid);
  if (mkdir(cgroupdir, 0777)) {
  }
  snprintf(file, sizeof(file), "%s/cgroup.procs", cgroupdir);
  write_file(file, "%d", pid);
  snprintf(file, sizeof(file), "%s/memory.soft_limit_in_bytes", cgroupdir);
  write_file(file, "%d", 299 << 20);
  snprintf(file, sizeof(file), "%s/memory.limit_in_bytes", cgroupdir);
  write_file(file, "%d", 300 << 20);
  snprintf(cgroupdir, sizeof(cgroupdir), "/syzcgroup/net/syz%llu", procid);
  if (mkdir(cgroupdir, 0777)) {
  }
  snprintf(file, sizeof(file), "%s/cgroup.procs", cgroupdir);
  write_file(file, "%d", pid);
}

static void setup_cgroups_test()
{
  char cgroupdir[64];
  snprintf(cgroupdir, sizeof(cgroupdir), "/syzcgroup/unified/syz%llu", procid);
  if (symlink(cgroupdir, "./cgroup")) {
  }
  snprintf(cgroupdir, sizeof(cgroupdir), "/syzcgroup/cpu/syz%llu", procid);
  if (symlink(cgroupdir, "./cgroup.cpu")) {
  }
  snprintf(cgroupdir, sizeof(cgroupdir), "/syzcgroup/net/syz%llu", procid);
  if (symlink(cgroupdir, "./cgroup.net")) {
  }
}

static void setup_common()
{
  if (mount(0, "/sys/fs/fuse/connections", "fusectl", 0, 0)) {
  }
}

static void setup_binderfs()
{
  if (mkdir("/dev/binderfs", 0777)) {
  }
  if (mount("binder", "/dev/binderfs", "binder", 0, NULL)) {
  }
}

static void loop();

static void sandbox_common()
{
  prctl(PR_SET_PDEATHSIG, SIGKILL, 0, 0, 0);
  setsid();
  struct rlimit rlim;
  rlim.rlim_cur = rlim.rlim_max = (200 << 20);
  setrlimit(RLIMIT_AS, &rlim);
  rlim.rlim_cur = rlim.rlim_max = 32 << 20;
  setrlimit(RLIMIT_MEMLOCK, &rlim);
  rlim.rlim_cur = rlim.rlim_max = 136 << 20;
  setrlimit(RLIMIT_FSIZE, &rlim);
  rlim.rlim_cur = rlim.rlim_max = 1 << 20;
  setrlimit(RLIMIT_STACK, &rlim);
  rlim.rlim_cur = rlim.rlim_max = 128 << 20;
  setrlimit(RLIMIT_CORE, &rlim);
  rlim.rlim_cur = rlim.rlim_max = 256;
  setrlimit(RLIMIT_NOFILE, &rlim);
  if (unshare(CLONE_NEWNS)) {
  }
  if (mount(NULL, "/", NULL, MS_REC | MS_PRIVATE, NULL)) {
  }
  if (unshare(CLONE_NEWIPC)) {
  }
  if (unshare(0x02000000)) {
  }
  if (unshare(CLONE_NEWUTS)) {
  }
  if (unshare(CLONE_SYSVSEM)) {
  }
  typedef struct {
    const char* name;
    const char* value;
  } sysctl_t;
  static const sysctl_t sysctls[] = {
      {"/proc/sys/kernel/shmmax", "16777216"},
      {"/proc/sys/kernel/shmall", "536870912"},
      {"/proc/sys/kernel/shmmni", "1024"},
      {"/proc/sys/kernel/msgmax", "8192"},
      {"/proc/sys/kernel/msgmni", "1024"},
      {"/proc/sys/kernel/msgmnb", "1024"},
      {"/proc/sys/kernel/sem", "1024 1048576 500 1024"},
  };
  unsigned i;
  for (i = 0; i < sizeof(sysctls) / sizeof(sysctls[0]); i++)
    write_file(sysctls[i].name, sysctls[i].value);
}

static int wait_for_loop(int pid)
{
  if (pid < 0)
    exit(1);
  int status = 0;
  while (waitpid(-1, &status, __WALL) != pid) {
  }
  return WEXITSTATUS(status);
}

static void drop_caps(void)
{
  struct __user_cap_header_struct cap_hdr = {};
  struct __user_cap_data_struct cap_data[2] = {};
  cap_hdr.version = _LINUX_CAPABILITY_VERSION_3;
  cap_hdr.pid = getpid();
  if (syscall(SYS_capget, &cap_hdr, &cap_data))
    exit(1);
  const int drop = (1 << CAP_SYS_PTRACE) | (1 << CAP_SYS_NICE);
  cap_data[0].effective &= ~drop;
  cap_data[0].permitted &= ~drop;
  cap_data[0].inheritable &= ~drop;
  if (syscall(SYS_capset, &cap_hdr, &cap_data))
    exit(1);
}

static int do_sandbox_none(void)
{
  if (unshare(CLONE_NEWPID)) {
  }
  int pid = fork();
  if (pid != 0)
    return wait_for_loop(pid);
  setup_common();
  sandbox_common();
  drop_caps();
  if (unshare(CLONE_NEWNET)) {
  }
  write_file("/proc/sys/net/ipv4/ping_group_range", "0 65535");
  setup_binderfs();
  loop();
  exit(1);
}

#define FS_IOC_SETFLAGS _IOW('f', 2, long)
static void remove_dir(const char* dir)
{
  int iter = 0;
  DIR* dp = 0;
retry:
  while (umount2(dir, MNT_DETACH | UMOUNT_NOFOLLOW) == 0) {
  }
  dp = opendir(dir);
  if (dp == NULL) {
    if (errno == EMFILE) {
      exit(1);
    }
    exit(1);
  }
  struct dirent* ep = 0;
  while ((ep = readdir(dp))) {
    if (strcmp(ep->d_name, ".") == 0 || strcmp(ep->d_name, "..") == 0)
      continue;
    char filename[FILENAME_MAX];
    snprintf(filename, sizeof(filename), "%s/%s", dir, ep->d_name);
    while (umount2(filename, MNT_DETACH | UMOUNT_NOFOLLOW) == 0) {
    }
    struct stat st;
    if (lstat(filename, &st))
      exit(1);
    if (S_ISDIR(st.st_mode)) {
      remove_dir(filename);
      continue;
    }
    int i;
    for (i = 0;; i++) {
      if (unlink(filename) == 0)
        break;
      if (errno == EPERM) {
        int fd = open(filename, O_RDONLY);
        if (fd != -1) {
          long flags = 0;
          if (ioctl(fd, FS_IOC_SETFLAGS, &flags) == 0) {
          }
          close(fd);
          continue;
        }
      }
      if (errno == EROFS) {
        break;
      }
      if (errno != EBUSY || i > 100)
        exit(1);
      if (umount2(filename, MNT_DETACH | UMOUNT_NOFOLLOW))
        exit(1);
    }
  }
  closedir(dp);
  for (int i = 0;; i++) {
    if (rmdir(dir) == 0)
      break;
    if (i < 100) {
      if (errno == EPERM) {
        int fd = open(dir, O_RDONLY);
        if (fd != -1) {
          long flags = 0;
          if (ioctl(fd, FS_IOC_SETFLAGS, &flags) == 0) {
          }
          close(fd);
          continue;
        }
      }
      if (errno == EROFS) {
        break;
      }
      if (errno == EBUSY) {
        if (umount2(dir, MNT_DETACH | UMOUNT_NOFOLLOW))
          exit(1);
        continue;
      }
      if (errno == ENOTEMPTY) {
        if (iter < 100) {
          iter++;
          goto retry;
        }
      }
    }
    exit(1);
  }
}

static void kill_and_wait(int pid, int* status)
{
  kill(-pid, SIGKILL);
  kill(pid, SIGKILL);
  for (int i = 0; i < 100; i++) {
    if (waitpid(-1, status, WNOHANG | __WALL) == pid)
      return;
    usleep(1000);
  }
  DIR* dir = opendir("/sys/fs/fuse/connections");
  if (dir) {
    for (;;) {
      struct dirent* ent = readdir(dir);
      if (!ent)
        break;
      if (strcmp(ent->d_name, ".") == 0 || strcmp(ent->d_name, "..") == 0)
        continue;
      char abort[300];
      snprintf(abort, sizeof(abort), "/sys/fs/fuse/connections/%s/abort",
               ent->d_name);
      int fd = open(abort, O_WRONLY);
      if (fd == -1) {
        continue;
      }
      if (write(fd, abort, 1) < 0) {
      }
      close(fd);
    }
    closedir(dir);
  } else {
  }
  while (waitpid(-1, status, __WALL) != pid) {
  }
}

static void setup_loop()
{
  setup_cgroups_loop();
}

static void reset_loop()
{
  char buf[64];
  snprintf(buf, sizeof(buf), "/dev/loop%llu", procid);
  int loopfd = open(buf, O_RDWR);
  if (loopfd != -1) {
    ioctl(loopfd, LOOP_CLR_FD, 0);
    close(loopfd);
  }
}

static void setup_test()
{
  prctl(PR_SET_PDEATHSIG, SIGKILL, 0, 0, 0);
  setpgrp();
  setup_cgroups_test();
  write_file("/proc/self/oom_score_adj", "1000");
  if (symlink("/dev/binderfs", "./binderfs")) {
  }
}

static void close_fds()
{
  for (int fd = 3; fd < MAX_FDS; fd++)
    close(fd);
}

struct thread_t {
  int created, call;
  event_t ready, done;
};

static struct thread_t threads[16];
static void execute_call(int call);
static int running;

static void* thr(void* arg)
{
  struct thread_t* th = (struct thread_t*)arg;
  for (;;) {
    event_wait(&th->ready);
    event_reset(&th->ready);
    execute_call(th->call);
    __atomic_fetch_sub(&running, 1, __ATOMIC_RELAXED);
    event_set(&th->done);
  }
  return 0;
}

static void execute_one(void)
{
  int i, call, thread;
  for (call = 0; call < 8; call++) {
    for (thread = 0; thread < (int)(sizeof(threads) / sizeof(threads[0]));
         thread++) {
      struct thread_t* th = &threads[thread];
      if (!th->created) {
        th->created = 1;
        event_init(&th->ready);
        event_init(&th->done);
        event_set(&th->done);
        thread_start(thr, th);
      }
      if (!event_isset(&th->done))
        continue;
      event_reset(&th->done);
      th->call = call;
      __atomic_fetch_add(&running, 1, __ATOMIC_RELAXED);
      event_set(&th->ready);
      if (call == 1 || call == 3)
        break;
      event_timedwait(&th->done, 50 + (call == 0 ? 4000 : 0));
      break;
    }
  }
  for (i = 0; i < 100 && __atomic_load_n(&running, __ATOMIC_RELAXED); i++)
    sleep_ms(1);
  close_fds();
}

static void execute_one(void);

#define WAIT_FLAGS __WALL

static void loop(void)
{
  setup_loop();
  int iter = 0;
  for (;; iter++) {
    char cwdbuf[32];
    sprintf(cwdbuf, "./%d", iter);
    if (mkdir(cwdbuf, 0777))
      exit(1);
    reset_loop();
    int pid = fork();
    if (pid < 0)
      exit(1);
    if (pid == 0) {
      if (chdir(cwdbuf))
        exit(1);
      setup_test();
      execute_one();
      exit(0);
    }
    int status = 0;
    uint64_t start = current_time_ms();
    for (;;) {
      if (waitpid(-1, &status, WNOHANG | WAIT_FLAGS) == pid)
        break;
      sleep_ms(1);
      if (current_time_ms() - start < 5000)
        continue;
      kill_and_wait(pid, &status);
      break;
    }
    remove_dir(cwdbuf);
  }
}

uint64_t r[3] = {0xffffffffffffffff, 0xffffffffffffffff, 0xffffffffffffffff};

void execute_call(int call)
{
  intptr_t res = 0;
  switch (call) {
  case 0:
    memcpy((void*)0x20000040, "ext4\000", 5);
    memcpy((void*)0x20000500, "./file1\000", 8);
    memcpy(
        (void*)0x20003e80,
        "\x00\xbf\x60\x42\xaa\xa5\xc8\x9f\x1a\xa1\xfc\xbc\xbb\xaa\x9c\xac\x31"
        "\xb2\x75\x03\xdf\x50\x07\x14\xd7\x94\x63\x48\x62\xc1\xe6\x0c\x6e\x22"
        "\xf9\x25\x56\x71\x3c\x0f\xe3\xf4\xe1\x3f\xa3\x61\x84\xa1\x61\x44\x77"
        "\x56\xdd\x0c\xf8\xdc\x7d\x5c\xea\x09\x88\xba\xf0\x3e\xfe\xbb\x63\xbd"
        "\x7a\x59\x83\xf0\x81\xf8\x11\xf1\x97\xb7\x8a\x5f\x5e\x95\x83\x8c\xc9"
        "\x0e\x64\x46\xd8\x18\x9c\x91\x21\xb3\xcc\xf5\xb2\x4d\x46\x84\x24\x2b"
        "\x4f\x85\xf6\xd4\x32\x31\xb7\xb9\x24\x0f\x74\xbd\xac\xf3\x4c\xb8\x60"
        "\x4b\x21\x79\x65\xc0\x2b\x7b\xe4\x19\x32\x6a\x31\x68\xc7\xdf\x4e\xb8"
        "\xdc\x2e\x7c\xc0\xd1\xc7\x08\xa1\x50\x28\x78\x63\x3e\xca\x49\xf3\x58"
        "\xe5\xb8\x55\x51\xff\x6e\x49\x77\x65\x08\xbf\x45\xb3\xc7\x1a\xf4\x15"
        "\x48\x93\x65\x64\xab\xd9\x9b\xb3\x4d\x1c\x23\x03\xb5\x1c\x29\xd0\x2f"
        "\xae\x2c\x7f\x03\x7b\xe4\xb4\xbc\x63\xea\xa6\x8a\x1e\x08\xe3\xfb\xc0"
        "\x77\x44\xa5\xdd\x13\x55\x53\xdb\x00\x6f\x1e\x0a\x90\x70\xbe\x08\x5a"
        "\x71\x8d\x79\x06\xa6\x8d\xc2\x6e\xc1\xf3\x19",
        232);
    memcpy(
        (void*)0x20000540,
        "\x78\x9c\xec\xdd\xdf\x6b\x5b\xd7\x1d\x00\xf0\xef\xbd\xb6\xb2\xfc\x70"
        "\x66\x67\xdb\x43\x16\x58\x16\x96\x0c\x27\x6c\x91\xec\x78\x49\xcc\x1e"
        "\xb2\x0c\xc6\xf2\x14\xd8\x96\xbd\x67\x9e\x2d\x1b\x63\xd9\x32\x96\x9c"
        "\xc4\x26\x0c\x87\xfd\x01\x83\x31\xd6\x42\x9f\xfa\xd4\x97\x42\xff\x80"
        "\x42\xc9\x9f\x50\x0a\x81\xf6\xbd\xb4\xa5\xa5\xb4\x49\xfb\xd0\x87\xb6"
        "\x2a\x92\xae\xd2\xc4\x95\x62\x87\xc8\xbe\x60\x7f\x3e\x70\x7c\xcf\xb9"
        "\x57\xd2\xf7\x7b\x6c\x74\x75\xcf\xbd\xc7\xba\x01\xec\x5b\xa7\x22\xe2"
        "\x6a\x44\x0c\x44\xc4\xb9\x88\x18\xce\xd6\xa7\x59\xb9\xd6\x6c\x6c\xb4"
        "\x1f\xf7\xe8\xe1\xdd\xe9\x66\x49\xa2\xd1\xb8\xf1\x59\x12\x49\xb6\xae"
        "\xf3\x5a\x49\xb6\x3c\xd2\x7e\x4a\x1c\x8c\x88\xbf\x5d\x8b\xf8\x67\xf2"
        "\xc3\xb8\xb5\xb5\xf5\x85\xa9\x4a\xa5\xbc\x92\xb5\x4b\xf5\xc5\xe5\x52"
        "\x6d\x6d\xfd\xfc\xfc\xe2\xd4\x5c\x79\xae\xbc\x34\x31\x31\x7e\x69\xf2"
        "\xf2\xe4\xc5\xc9\xb1\xbe\xf4\x73\x24\x22\xae\xfc\xe9\xa3\xff\xff\xe7"
        "\xb5\x3f\x5f\x79\xeb\xb7\xb7\xdf\xbf\xf9\xc9\xd9\x7f\x35\xd3\x1a\xca"
        "\xb6\x3f\xd9\x8f\x7e\x6a\x77\xbd\xd0\xfa\x5d\x74\x0c\x46\xc4\xca\x4e"
        "\x04\xcb\xc1\x40\xb6\x2c\xe4\x9c\x07\x00\x00\xdb\xd3\x3c\xc6\xff\x49"
        "\x44\xfc\xaa\x75\xfc\x3f\x1c\x03\xad\xa3\x53\x00\x00\x00\x60\x2f\x69"
        "\xfc\x61\x28\xbe\x4e\x22\x1a\x00\x00\x00\xc0\x9e\x95\xb6\xe6\xc0\x26"
        "\x69\x31\x9b\x0b\x30\x14\x69\x5a\x2c\xb6\xe7\xf0\xfe\x2c\x0e\xa7\x95"
        "\x6a\xad\xfe\x9b\xd9\xea\xea\xd2\x4c\x7b\xae\xec\x48\x14\xd2\xd9\xf9"
        "\x4a\x79\x2c\x9b\x2b\x3c\x12\x85\xa4\xd9\x1e\xcf\xe6\xd8\x76\xda\x17"
        "\x36\xb5\x27\x22\xe2\x58\x44\xfc\x6f\xf8\x50\xab\x5d\x9c\xae\x56\x66"
        "\xf2\x3e\xf9\x01\x00\x00\x00\xfb\xc4\x91\x4d\xe3\xff\x2f\x87\xdb\xe3"
        "\x7f\x00\x00\x00\x60\x8f\x19\xc9\x3b\x01\x00\x00\x00\x60\xc7\x19\xff"
        "\x03\x00\x00\xc0\xde\x67\xfc\x0f\x00\x00\x00\x7b\xda\x5f\xae\x5f\x6f"
        "\x96\x46\xe7\xfe\xd7\x33\xb7\xd6\x56\x17\xaa\xb7\xce\xcf\x94\x6b\x0b"
        "\xc5\xc5\xd5\xe9\xe2\x74\x75\x65\xb9\x38\x57\xad\xce\xb5\xbe\xb3\x6f"
        "\x71\xab\xd7\xab\x54\xab\xcb\xbf\x8b\xa5\xd5\x3b\xa5\x7a\xb9\x56\x2f"
        "\xd5\xd6\xd6\x6f\x2e\x56\x57\x97\xea\x37\xe7\x9f\xba\x05\x36\x00\x00"
        "\x00\xb0\x8b\x8e\xfd\xf2\xfe\x7b\x49\x44\x6c\xfc\xfe\x50\xab\x34\x1d"
        "\xc8\x3b\x29\x60\x57\x24\xcf\xf3\xe0\x0f\x77\x2e\x0f\x60\xf7\x0d\xe4"
        "\x9d\x00\x90\x9b\xc1\xbc\x13\x00\x72\x53\xc8\x3b\x01\x20\x77\x5b\x9d"
        "\x07\xe8\x39\x79\xe7\xed\xfe\xe7\x02\x00\x00\xec\x8c\xd1\x9f\xf7\xbe"
        "\xfe\xef\xdc\x00\xec\x6d\x69\xde\x09\x00\x00\xbb\xce\xf5\x7f\xd8\xbf"
        "\x0a\x66\x00\xc2\xbe\xf7\xe3\x2d\xb6\xbf\xf8\xf5\xff\x46\xe3\xb9\x12"
        "\x02\x00\x00\xfa\x6e\xa8\x55\x92\xb4\x98\x5d\x0b\x1c\x8a\x34\x2d\x16"
        "\x23\x8e\xb6\x6e\x0b\x50\x48\x66\xe7\x2b\xe5\xb1\x6c\x7c\xf0\xee\x70"
        "\xe1\x47\xcd\xf6\x78\xeb\x99\xc9\xf3\xfd\xef\x30\x00\x00\x00\x00\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xec\x63\x8d"
        "\x46\x12\x0d\x00\x00\x00\x60\x4f\x8b\x48\x3f\x4e\x5a\xdf\xe6\x1f\x31"
        "\x3a\x7c\x66\x68\xf3\xf9\x81\x03\xc9\x57\xc3\xad\x65\x44\xdc\x7e\xe5"
        "\xc6\x4b\x77\xa6\xea\xf5\x95\xf1\xe6\xfa\xcf\x1f\xaf\xaf\xbf\x9c\xad"
        "\xbf\x90\xc7\x19\x0c\x00\x00\x00\x60\xb3\xce\x38\xbd\x33\x8e\x07\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\x80\x7e\x7a\xf4\xf0\xee\x74\xa7\xec\x66\xdc\x4f\xff\x18\x11"
        "\x23\xdd\xe2\x0f\xc6\xc1\xd6\xf2\x60\x14\x22\xe2\xf0\x17\x49\x0c\x3e"
        "\xf1\xbc\x24\x22\x06\xfa\x10\x7f\xe3\x5e\x44\x1c\xef\x16\x3f\x69\xa6"
        "\x15\x23\x59\x16\xdd\xe2\x1f\xca\x31\x7e\x1a\x11\x47\xfa\x10\x1f\xf6"
        "\xb3\xfb\xcd\xfd\xcf\xd5\x6e\xef\xbf\x34\x4e\xb5\x96\xdd\xdf\x7f\x83"
        "\x59\x79\x51\xbd\xf7\x7f\xe9\xe3\xfd\xdf\x40\x8f\xfd\xcf\xd1\x6d\xc6"
        "\x38\xf1\xe0\x8d\x52\xcf\xf8\xf7\x22\x4e\x0c\x76\xdf\xff\x74\xe2\x27"
        "\x3d\xe2\x9f\xde\x66\xfc\x7f\xfc\x7d\x7d\xbd\xd7\xb6\xc6\xab\x11\xa3"
        "\x5d\x3f\x7f\x92\xa7\x62\x95\xea\x8b\xcb\xa5\xda\xda\xfa\xf9\xf9\xc5"
        "\xa9\xb9\xf2\x5c\x79\x69\x62\x62\xfc\xd2\xe4\xe5\xc9\x8b\x93\x63\xa5"
        "\xd9\xf9\x4a\x39\xfb\xd9\x35\xc6\x7f\x7f\xf1\xe6\xb7\xcf\xea\xff\xe1"
        "\x1e\xf1\x47\xb6\xe8\xff\x99\x6d\xf6\xff\x9b\x07\x77\x1e\xfe\xb4\x5d"
        "\x2d\x74\x8b\x7f\xf6\x74\xf7\xcf\xdf\xe3\x3d\xe2\xa7\xd9\x67\xdf\xaf"
        "\xb3\x7a\x73\xfb\x68\xa7\xbe\xd1\xae\x3f\xe9\xe4\xeb\xef\x9c\x7c\x56"
        "\xff\x67\x7a\xf4\x7f\xab\xbf\xff\xd9\x6d\xf6\xff\xdc\x5f\xff\xfd\xc1"
        "\x36\x1f\x0a\x00\xec\x82\xda\xda\xfa\xc2\x54\xa5\x52\x5e\x51\x51\x51"
        "\x51\x79\x5c\xc9\x7b\xcf\x04\x00\x00\xf4\xdb\xf7\x07\xfd\x79\x67\x02"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xfb\xd7"
        "\x6e\x7c\x9d\xd8\xe6\x98\x1b\xf9\x74\x15\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
        "\x00\x00\xe0\x99\xbe\x0b\x00\x00\xff\xff\xf7\xa0\xd4\xed",
        1204);
    res = -1;
    res = syz_mount_image(/*fs=*/0x20000040, /*dir=*/0x20000500,
                          /*flags=*/0x4500, /*opts=*/0x20003e80, /*chdir=*/0x12,
                          /*size=*/0x4b4, /*img=*/0x20000540);
    if (res != -1)
      r[0] = res;
    break;
  case 1:
    memcpy((void*)0x20000180, "./bus\000", 6);
    syscall(__NR_open, /*file=*/0x20000180ul, /*flags=*/0x14d27eul,
            /*mode=*/0ul);
    break;
  case 2:
    memcpy((void*)0x20000180, "./bus\000", 6);
    res = syscall(__NR_open, /*file=*/0x20000180ul, /*flags=*/0x14d27eul,
                  /*mode=*/0ul);
    if (res != -1)
      r[1] = res;
    break;
  case 3:
    syscall(__NR_fallocate, /*fd=*/r[1], /*mode=*/0ul, /*off=*/0x8947ul,
            /*len=*/7ul);
    break;
  case 4:
    memcpy((void*)0x20000380, "/dev/loop", 9);
    *(uint8_t*)0x20000389 = 0x30 + procid * 1;
    *(uint8_t*)0x2000038a = 0;
    memcpy((void*)0x20000140, "./bus\000", 6);
    syscall(__NR_mount, /*src=*/0x20000380ul, /*dst=*/0x20000140ul,
            /*type=*/0ul, /*flags=*/0x1000ul, /*data=*/0ul);
    break;
  case 5:
    memcpy((void*)0x200000c0, "./bus\000", 6);
    res = syscall(__NR_open, /*file=*/0x200000c0ul, /*flags=*/0x14113eul,
                  /*mode=*/0ul);
    if (res != -1)
      r[2] = res;
    break;
  case 6:
    memcpy(
        (void*)0x20002a80,
        "\x5d\x0f\x1b\xc7\x13\x63\xce\x46\xd7\xd6\x8a\x9a\x08\x09\x94\xde\x4f"
        "\x56\xb8\x75\x79\xb6\x4c\x51\x1a\xae\x21\xa9\x1e\xb2\xdb\x3a\x04\x37"
        "\xf8\x48\xb7\x71\xb3\xc3\xb8\x06\x60\x1d\x4b\x7a\x5f\x1e\x7c\xb6\x0a"
        "\x34\xda\x12\xb2\x6f\xad\xc9\x46\xcc\xd2\x3b\x6a\xfb\x12\xc1\xce\xe6"
        "\x20\x8b\xb8\xae\x2e\x2b\x32\x28\xe7\xeb\x78\x4c\x60\x8b\x9a\x07\xad"
        "\x74\x7b\x94\x3a\x77\x03\xd8\xca\xcb\x26\xad\x1e\x02\xca\x87\xd6\x0c"
        "\x5a\x5d\xe2\xec\x40\x30\xfc\x27\xae\x98\xc7\xf3\x23\x7f\xd3\x68\xa8"
        "\x16\x64\xac\x23\x6a\x8e\xd6\xda\xbb\x66\x98\x9b\xec\x92\x8b\x60\x24"
        "\x5a\xfc\x81\x47\x96\x4e\x94\x35\x40\x50\x26\x33\x5f\x56\xff\x99\x66"
        "\x1b\xc1\xf3\x3e\x53\x48\xd8\x09\xc8\x98\xdb\x46\x4c\x07\x30\x20\xb5"
        "\xd1\x10\x21\xe9\xbd\xd8\x37\x6a\xf6\x39\xc7\x69\xa1\xee\x3a\x94\x60"
        "\x3a\xe4\x03\xe9\x35\x10\xf4\xce\xf0\x6b\xd4\xde\xd3\xb7\xff\x22\xd6"
        "\xdf\x0c\xbd\x74\x77\x7b\x40\xa4\xbd\x9f\x59\xa7\x1c\x4d\x07\x40\xb1"
        "\xac\xfe\x9f\xe4\xc2\x1b\xae\x5a\x59\xfe\x15\x1c\x23\x27\xfe\xd5\xa3"
        "\x19\xf9\x93\xbb\x61\xb3\x00\x3c\x97\x74\xf0\x3e\xeb\xf0\x5b\xa4\x29"
        "\x85\x07\x7b\x45\x1e\x31\xfb\x01\x95\xaa\xc0\x11\xb7\x0a\xcc\x13\xb5"
        "\x41\x35\x4d\x1c\xd9\x09\x3e\x35\xb8\x91\x52\xec\x43\x5e\x05\xd6\x22"
        "\x10\xc2\x8b\x36\xe1\x0a\xbc\xde\x5a\x81\xbb\xf1\x9e\xe5\x33\xfa\xf6"
        "\xeb\xae\x10\xc3\xa6\xf8\xdd\xd9\x48\xa6\x27\xd7\xb0\x17\xd5\xf5\x9d"
        "\x62\xcd\xf3\xef\x76\x20\xef\x9c\x16\x14\x26\x16\x03\xae\x93\x94\x11"
        "\xf8\xc3\x3b\xdd\xee\x8f\x74\x93\xd2\xfb\x8d\x08\xdb\x04\x99\x6f\x18"
        "\x61\xfe\x5c\xff\xb1\x0f\x81\x7a\x36\xd1\x17\x01\x60\x2e\x44\x2e\x6d"
        "\xc8\x38\x95\x3d\xfe\xd4\xc7\x42\x6c\xed\x45\xe4\xf0\x32\x7e\xe3\x69"
        "\xa7\x7c\xcc\xef\x51\xaf\x2d\x85\x20\x54\x00\x26\x47\xb4\x66\x13\xa8"
        "\xe5\xd0\xf1\xd1\x63\x2d\xa0\xe3\x5a\x5e\x6e\x8c\xb8\xd2\x5d\xe7\x5c"
        "\xab\xd4\x1d\xc4\x4a\x53\x33\x39\xca\x2d\xe5\xc4\xa7\x34\x54\xc9\x30"
        "\xd4\x1c\x64\x3f\xd4\x1e\x2e\x93\x94\xdc\x2e\x17\x49\x50\x2f\x04\x0c"
        "\x41\xda\x2a\x2d\x97\x82\xba\x17\x49\xbd\x08\x33\x2f\xc7\x7c\x5b\xf6"
        "\x64\xcb\x27\xc0\xb0\x4c\x0e\x0e\x29\x2d\x7a\xa0\xc8\x48\x3c\x42\xf8"
        "\x6f\xf2\xda\xee\x69\xea\x2a\xb3\x8f\xf6\x35\x5e\x6c\x23\x67\xc7\xb9"
        "\xde\xd7\x08\x17\x38\x96\xb6\x74\xa0\x3c\xde\x0d\x11\x55\x5f\x6f\x36"
        "\x3c\x11\xcb\xa6\xd0\x27\x4f\xc9\xc6\xd1\x3a\x71\x5d\x0b\x0d\x3c\x9a"
        "\x4b\x8e\xad\x91\x35\x31\xe3\x39\x8b\xcf\xe6\xe2\xbc\x2f\xe9\x4d\x3a"
        "\xae\xae\xe1\x60\xbf\x89\xbd\x20\xb4\x65\x64\xc7\x69\xb7\x5c\x24\x4d"
        "\xa0\x36\x58\x2b\xf8\xac\x8a\x1a\xcb\x70\x4d\x70\x9e\xf8\x8a\xb3\xfe"
        "\xad\xf3\x20\xa9\x2d\x79\x0b\x08\x3f\xfa\x6c\x99\x73\x12\xc9\x5b\xa8"
        "\x75\xc7\x0a\x13\xb3\x79\x29\x7d\x9d\x66\xd9\xdc\x5f\x94\x79\x13\x25"
        "\x64\xb2\x19\x0b\x21\x5b\x2e\x33\x56\x71\xd6\x4e\xfa\xa8\xe6\xb6\xe1"
        "\x30\x81\x3f\xf5\x5a\x49\x4f\x26\x60\xe8\xa4\x4f\x18\xca\x44\x30\x53"
        "\x16\x70\xc3\x99\xc1\x8c\x19\x29\x97\xe2\x22\xe6\x47\xd2\x6c\x14\x41"
        "\xd4\x18\xf9\xd8\xbc\xdc\x7a\x01\x6e\xf4\x65\x1c\x01\x34\x66\x97\x5f"
        "\x60\x83\x9f\xe9\xea\xf8\x72\x36\x03\x52\x04\xf1\x1f\x05\x16\x41\x0a"
        "\x61\xd1\x44\x13\xd7\x9b\x11\x51\x13\x68\x44\xd7\x2d\xad\xfd\x52\x6e"
        "\x9b\x18\xb4\xe5\x94\x2f\x1e\xa7\xa9\xd5\x1d\x2c\x8e\x2b\x48\xc4\xf1"
        "\x44\xf8\x01\x67\x10\xd6\x80\x6d\x64\x29\xc6\xe1\xbb\x8a\x3c\x7b\x95"
        "\x40\x47\xfc\xa2\x86\x45\x31\x76\xbb\xc0\x16\xeb\x2f\x7d\x44\x51\x85"
        "\x92\x16\x41\xfe\x50\xff\x00\x58\x62\xdb\xd1\x3e\x47\xf5\x59\x48\xa5"
        "\x47\x31\xe0\xbb\x11\xa5\x05\x23\x80\xc5\xf3\x10\x51\x69\xc8\x82\xb4"
        "\x15\x8b\x33\x6b\x31\x8e\xd9\x00\x86\x93\x0f\x98\x8e\xbb\xcf\xce\x0f"
        "\x56\x5c\x08\x3b\x5e\xd4\xa5\xe0\x48\xb2\x3a\x08\xe1\x62\x4a\x18\x85"
        "\x01\xa1\x72\xef\x9f\xe8\xeb\x76\x0a\x27\x15\x77\xf5\xa5\x74\xcf\xd2"
        "\x30\xa8\xf5\xb5\x53\xed\x8b\xc2\x12\x0c\x0d\x22\xda\xa9\x5f\xe6\x34"
        "\xb1\xb3\xfd\xc2\xa5\x05\x65\x6c\xdc\xa3\x3d\xfc\xed\x21\x1f\xb0\xf5"
        "\x30\x20\x91\x73\x8c\xdc\x4c\xcc\x18\x89\x6b\xcd\x3a\xa9\xb8\xa9\x5c"
        "\xda\x0d\x5b\x88\x9c\x82\x21\x00\x3d\x35\xde\x41\xb2\xe6\xbd\x34\xa7"
        "\x73\x06\x0c\xd9\xad\xe8\xa2\x1c\xd7\x2b\x77\x34\xdf\x0b\x0e\x49\x03"
        "\xd0\x48\xac\xcb\xd3\x4a\xe4\x56\x05\x08\x63\x7d\x7d\xff\x90\x65\x49"
        "\x6f\xe1\xfe\xd5\xbb\x01\xf9\xd2\x64\x48\x80\x71\xba\x58\x9a\x54\x3f"
        "\xdf\x28\x13\xb0\x00\x1d\x7f\x01\x84\x91\x4c\xae\x7e\xaa\x7a\xec\xa4"
        "\x1d\xc8\x9d\xd5\x3a\x95\x56\x65\x5b\x10\xe8\xc6\x11\x5f\x1d\x1a\x27"
        "\x1f\xe5\xdc\x5c\xc5\x7f\x63\x38\x3f\xc1\x11\x23\x8c\x90\xa8\x00\xc6"
        "\xe9\x73\x80\xc6\xd0\x6b\x09\xd8\xab\x0f\x89\x47\xbf\x4c\xe1\x84\x26"
        "\xa3\xc1\xa9\xd6\xdb\x7f\x16\x49\xa8\x91\xdf\xdd\x80\x21\x20\x87\xe0"
        "\x27\x01\x48\x29\x78\x19\xd9\x34\xea\xfd\x20\xea\x74\x1d\x90\x88\x32"
        "\x00\x24\x9a\x5c\x98\xac\x2f\xa1\x49\xc3\xd5\x07\x07\x81\x95\xbd\x38"
        "\xfa\x81\x10\x97\x31\x94\x33\x12\x03\xb0\x7a\xf3\xe7\xb8\x6a\x62\x50"
        "\x1c\xb8\x16\x13\x2c\x7e\xf6\xfc\xcb\x6a\x97\x4c\xb3\x06\x70\x1a\x9f"
        "\xf9\x80\x71\xbb\x87\x8e\x5e\xe8\xcd\x20\x48\xa7\x6d\x69\x57\xf1\x1c"
        "\x66\x95\xec\x89\x91\x8b\xe8\x22\x9c\xc5\xf0\x78\xaa\x9b\x03\x7f\x6f"
        "\x7f\xed\x41\x45\xd8\xf1\xa3\xb6\x83\x75\xae\xb9\x6e\x70\x01\xe4\xa1"
        "\x08\x64\x28\x27\xf8\xea\xf2\xbf\xf8\xc8\xe9\xdd\xee\xa5\x06\x67\x62"
        "\x21\x7e\x0e\x4c\xd3\x1a\x81\x16\x2e\xa1\x86\x1f\xa9\xa6\x15\x21\xfd"
        "\x7c\xf9\xc6\x49\x32\xad\x27\x43\xea\x7f\x1c\x89\xe2\x30\x18\x9c\x86"
        "\xa4\x9d\x14\x55\x46\x91\x50\xf3\x7a\x4b\xff\x62\xa2\x3c\x97\x90\xae"
        "\x88\x2e\x4e\x74\x98\xa4\x6c\x98\xcc\xc9\xc2\xa0\xc5\xee\x6d\x13\xae"
        "\x30\x37\xf1\x35\xb8\x5d\x7c\x9d\x38\xc7\x24\x2a\x9b\x2a\x58\xf5\xd6"
        "\x03\x9a\xe6\x4b\x50\x2b\x9b\x64\x6c\xa6\x59\x70\x83\x10\x2f\x91\xeb"
        "\xbe\x5b\xaa\x84\x18\xd4\x5d\x29\xdd\xc1\x50\x94\xa9\x90\x90\xf4\x5c"
        "\xc1\xb5\x13\xbc\x3e\x20\x56\x44\xf7\xa6\xe4\x4e\x78\x99\xd6\x06\x1b"
        "\x10\x46\xa9\xf2\xfe\x96\x46\x67\x60\x33\xc1\x12\x2e\x6d\x1e\xf8\x99"
        "\x09\x80\x92\xff\x86\x5f\x8d\xea\x2c\x85\x3f\x6b\x48\x4e\x7d\x38\x43"
        "\x7d\x2b\xf8\xcb\x57\x48\x7f\x63\x8f\x48\x01\x00\x85\xfd\xf9\x69\xb2"
        "\x4f\x1c\x10\x78\xef\xfd\xbc\x3d\xf2\x24\xb3\x3c\x93\xe4\xe6\x2b\x2c"
        "\x45\xfe\xa3\xf2\x81\x7a\x9e\xb0\x51\x95\xa2\xfd\xbd\xf9\x9c\xc3\x22"
        "\xaa\x3f\x95\x73\x1c\xa1\x23\x76\xdd\x6b\x94\xff\xcf\x07\xa3\x3e\xde"
        "\x44\x24\xcd\x89\xf8\x13\xf9\x85\x18\xce\x8d\x33\xba\x10\xe3\xf1\x84"
        "\x8a\xf4\xda\x33\x4e\x0e\x61\xe7\x65\x6d\x97\xbb\x0d\x96\x9b\xbb\xba"
        "\x4f\xac\x41\x21\x58\xe1\x3c\x5c\xbf\x8e\x88\xbb\xd1\x5c\xa4\xd8\xc7"
        "\x03\xe2\x66\xa2\xec\x70\xaa\x14\x65\x0a\x2f\x12\xba\x02\xc1\x8c\x28"
        "\x63\xf1\x6a\x2d\xde\xb2\x5e\x8a\x9c\x33\xf5\x5b\x3c\xb0\x98\x1f\x2d"
        "\x31\xaa\x2f\x8c\xaa\x77\xe6\x1f\x7e\x8a\xfe\x6a\x13\xcb\xfb\x46\xc1"
        "\x96\xd3\x53\xc9\x61\x2f\x92\x5b\xa9\x46\x11\x28\xfa\xe3\xd6\x24\xc9"
        "\x21\xe8\xf1\xec\x54\xb3\xa9\x19\x64\xfd\x0b\xa2\xe0\x65\x0e\x04\x4d"
        "\xec\xb8\x2d\x0f\xcd\x99\x46\x18\x81\x78\x15\x8f\x73\xd1\xa4\x40\xf5"
        "\x79\x41\xb7\x97\x4e\x8b\xce\xd4\xef\x72\x92\x88\x6c\x41\x36\xac\x41"
        "\xb0\x66\xab\x04\x02\xe7\x5d\x58\xc6\x7d\x4d\xe8\x32\x13\x4a\x7a\xbe"
        "\x19\x6c\xb9\xd1\xc0\x98\x82\x1a\x7b\xd4\x86\x05\x54\xbc\xcf\x44\x08"
        "\xaf\x87\x04\xa3\xda\xe1\x8f\x3e\xaf\x70\xcd\x28\xa4\x47\xa6\xcf\x44"
        "\x32\x66\x66\xb8\x09\xcf\xdb\x3d\x5f\x13\xab\x93\x64\x94\x2c\x10\xa4"
        "\x46\x1e\x33\x8e\xef\xa2\x65\x13\xcd\xe2\x1e\xd4\xfd\xe2\x93\xf9\x5b"
        "\xcf\xd9\xe1\xde\x36\xf1\xa9\x2a\xf8\x73\x29\xcc\xfa\x51\x17\x3b\x6f"
        "\x72\x77\x36\xd1\x39\x73\x06\xe0\x3d\x83\x31\xdd\x50\x72\x26\xf7\x1e"
        "\x02\x80\xf1\xa6\x9d\xe5\x5a\x14\xee\xd5\x87\x37\xb4\x8e\x08\x57\x43"
        "\x49\xae\x95\x0e\x41\xa1\x89\xaa\xc6\x17\x7f\xa4\x21\x66\x48\x2d\x6a"
        "\x52\xeb\x05\x03\x67\xdd\xe9\x55\xaf\x68\x89\x9f\x91\xa7\x44\x07\x65"
        "\x19\x07\xa7\xed\xa3\x8c\x6b\xcd\xfb\x9e\x18\x97\x64\xa1\xd9\xbf\x18"
        "\x17\x24\x69\x27\x54\x93\x54\xd5\xc4\x84\xf1\x60\x8c\x92\xda\x48\x1a"
        "\xdc\x18\xe9\x81\x6a\xe7\x4f\x3b\x02\xbe\x68\x0e\xa4\xf4\xa9\x1f\x56"
        "\x77\x48\x2c\xdb\x6b\x70\x3d\x8b\x4a\x7d\x99\x92\x47\x7d\x79\x63\x4b"
        "\xde\x3c\xab\xa8\x5a\xcc\xfc\xe9\x54\x19\x09\xc4\x18\xa2\x20\x19\xd9"
        "\x9a\xe6\xd9\x84\x61\x11\x2b\x93\xc3\x5c\x86\x40\xb9\xa3\x33\x6c\x64"
        "\x9f\x2d\x04\xe3\xcc\x27\x11\xf8\x82\x1f\x73\x24\xec\xcc\xfa\x96\xcb"
        "\xea\xb4\xd0\x25\x77\x19\x09\x05\x2b\xaa\x66\x71\xc3\xaf\x66\x54\x5d"
        "\xdd\x0c\xb0\xe2\x65\x2b\x76\x39\xcf\x40\x65\x29\xea\x59\x5a\x63\x0e"
        "\x64\x88\xab\x5e\x5f\xee\x1e\x54\xd6\x36\x19\xc7\xa3\xaa\x3e\x1e\x0e"
        "\x3b\x8c\x86\x93\xc2\xb1\xb5\x93\x80\xec\xdb\xb8\xde\x7e\x74\x93\x80"
        "\xba\x5c\xc4\x0d\x64\x75\x5d\xf1\x79\x76\xab\x6d\x49\x26\x49\xe2\x93"
        "\xb8\xf2\xdb\xc5\x1a\x3b\x73\x8c\xdd\x37\xed\xe4\x2d\x6d\x82\x9e\xe7"
        "\x1b\xbe\xbe\xe4\xcb\x51\x21\xed\xf9\xd5\x01\xb3\x7c\xb3\x31\xfa\xd8"
        "\xbe\xe7\x5e\xe6\xa4\xe3\x9f\x46\xa4\x62\xda\xa2\x4e\x60\xfb\xbc\x49"
        "\x0b\x76\x61\xe3\x6f\xfc\xdd\xb8\x5c\x53\xa6\x68\xe3\xb5\x75\xcd\xff"
        "\x78\x12\x8c\xc0\xbc\x30\xc0\x26\xdd\xde\x90\x9c\x22\x58\x7b\x0c\x0d"
        "\x26\x79\x0c\xce\x95\xec\x4f\x62\x6b\x60\x40\xac\xb0\x39\xd4\xfb\xa1"
        "\xfb\x19\x74\xa9\x10\xf2\xa3\x21\x97\xa6\x97\x2f\x11\x87\x5a\x4c\x0c"
        "\xc7\x22\x5c\x91\xe5\x9b\x82\xf7\x8e\x0c\x09\xc1\xf5\x38\xe7\xa7\x42"
        "\xfd\x3d\xc7\x48\xdc\x4f\x27\x38\x9a\xec\x38\x36\xf6\xc2\xd1\xad\xc3"
        "\x50\x81\x05\x58\x0e\x60\x7b\x3f\x5f\xbe\xa3\x47\xd7\x8c\xf7\xfc\xcd"
        "\x94\x31\x88\xad\x2a\xde\x4f\x0b\xdc\x58\x43\x3d\x46\xd5\xbd\xe7\xea"
        "\x7f\x93\xce\x35\x23\x83\xbc\xe9\x6b\x3a\xaf\xb3\x5e\x7c\xdd\x75\x21"
        "\xf6\x24\x24\x32\x5a\x7b\xba\xe9\x0a\x74\x81\x5b\xa3\x2b\x11\xf2\xb2"
        "\x9a\x33\x5c\x9a\xd0\xf1\x76\x8a\x96\x0c\xe2\x5b\x78\x0a\x55\x43\x21"
        "\xf5\x98\xe4\x4d\x11\x10\x99\xe7\xa7\xcb\x67\x9a\xd1\x4a\x37\x46\x53"
        "\x18\x3c\x77\x3f\xe2\xea\x7b\xb1\xae\x48\xba\xb4\x1c\xd0\x2a\xed\xbd"
        "\x74\x48\x30\x8a\x36\xe7\x64\x17\xd3\x84\x07\x32\x16\x93\xd3\x3b\xa8"
        "\xb6\xf7\xfc\x1e\xf7\x77\xe4\x86\x82\x25\xe5\xa6\xf9\x9b\xe6\xc0\xea"
        "\x7b\x23\xfa\x2c\xc9\xc3\xb8\x9d\x29\x38\x5c\x35\x71\x28\x41\xda\xf2"
        "\x3b\xb4\xa1\x5a\x56\x98\xc8\xd7\x0a\x73\x8f\x16\xdb\x5b\xec\x47\x07"
        "\x72\x7f\xf3\xca\x44\xed\x0e\x11\x98\x03\xd6\xae\x9e\xa3\x49\x21\xaa"
        "\xf3\x80\x8e\xfa\xa4\x1c\x23\x04\xf0\x74\xb7\x83\xf5\x5f\xce\xe3\x3d"
        "\x42\x84\xc3\x3a\xc0\x8f\x96\xc4\x87\xe0\xd3\x01\x82\xfc\x8c\x5e\xb3"
        "\xe9\xb0\x77\x0c\xf9\x6f\x3a\x14\x9f\xd2\x13\x6f\xdb\xfc\xe0\xd5\x4a"
        "\xcf\x69\x0a\xc2\xe7\xf4\xe6\x8c\xd9\x73\xab\x51\x4e\x1a\x2c\xf9\x01"
        "\x57\xa5\x56\xca\xdc\x00\xc0\x08\xd2\x39\x07\xbd\x23\xef\x76\x78\x67"
        "\xb5\xe4\x6c\x8b\x6c\x93\xec\xf4\x00\x86\x77\x9a\xb5\x8e\x01\x99\x53"
        "\x5b\xbc\x1f\x18\xb2\xbc\x16\x03\x66\xe5\x9e\xfa\x92\x9b\x27\x86\xd0"
        "\xee\xf3\x0e\x79\x4b\x64\x40\xd3\x8c\x2b\x8d\x5a\xf5\x8a\x05\x95\x53"
        "\xc3\xc5\xc6\x20\xf6\x56\x32\x30\x2e\xc9\x79\x46\xfa\xa5\x0f\x39\x0f"
        "\x49\x07\x91\x67\x6c\x85\x34\x86\xb3\xa2\x61\x32\x84\x86\x1b\x5d\xbe"
        "\x6d\x21\x42\xa2\xea\x48\x5c\x3f\x61\x14\x9c\x18\x92\x29\x80\x0c\x52"
        "\xe8\xeb\x81\x00\xcb\x9b\x11\x4e\x71\x2e\xe8\x15\x97\x9e\x3e\x31\x9a"
        "\x96\xd4\x4c\xd2\x54\x11\x3e\x88\x30\xc0\x44\xf4\xe1\x86\x21\x7a\x83"
        "\x9b\x30\xb7\x7b\x18\xa5\x7b\x96\x1b\x9d\xcb\xdc\xf0\xce\xed\x4f\x3e"
        "\x68\x98\xa6\x1a\xd0\x02\x05\x11\xfd\x53\x56\x22\xce\xcd\x36\xb1\x61"
        "\x43\xe6\x0c\xd0\x01\x31\xd1\x3c\x7e\x1b\xa1\xbd\xca\x5d\x61\x2d\xed"
        "\xfb\x14\x6e\x87\xcf\xa5\xd0\xa0\xb7\x22\x6f\x90\x41\xdc\xbd\xb5\x87"
        "\x20\xe2\xcb\x67\x9d\x9a\x32\xe5\x24\x83\x9c\x1d\x0c\xf9\x5e\x6f\xcd"
        "\xb0\xc6\x69\xd4\x60\xa0\xd8\x1e\xc9\x14\xa0\x13\xe7\xee\x89\xa1\x91"
        "\x7b\x90\x8f\xe7\xa1\x78\x91\x08\xe5\x55\x80\xb9\x77\xc7\x27\xfa\x8e"
        "\xed\xa6\x07\xc2\x2a\x1d\xac\x71\x41\xa6\x35\xa8\xb9\x3c\x64\x1f\x89"
        "\x5a\x58\x05\x04\x31\x03\xc3\xfe\x7b\x5b\xd2\x84\x62\xd7\xeb\x92\x7f"
        "\xee\xdd\xb4\xae\x25\xbb\x7e\x0b\x3c\x4e\x8c\xe0\xf8\xd0\x62\x70\x63"
        "\x1f\x16\x2b\xa8\x65\x84\x9a\x36\x95\x5e\xd8\x51\xab\x76\x8f\x5d\xa4"
        "\xb3\x3f\x05\x25\xde\x9a\x9e\x09\xbd\x25\xc6\x46\xdb\x2b\x2e\xbd\x64"
        "\xee\x98\x12\x6d\xbf\xb0\xc2\x7b\x5b\x70\x8a\x4b\xb1\x18\x54\x50\x80"
        "\x42\x2a\x0a\xae\xdc\x99\xfc\xba\xbb\x3e\x8a\xbe\x0f\xb7\x4d\xb2\x67"
        "\xcd\xa3\xd4\x8c\x75\x4c\xf6\xb5\x79\x82\x20\x9a\xaf\xca\xfb\xd9\x02"
        "\x8c\x0c\x5f\xe2\xdf\x36\x6c\xb7\x93\x86\x03\x66\xea\x79\x6b\x6e\x8c"
        "\x93\x35\x17\x5f\x46\x7f\x3f\x4c\xe1\x53\xe3\x1f\xf4\x2d\x46\x2d\x31"
        "\x29\xe4\x49\x54\x63\x8b\xb7\x22\xe2\x28\x40\x13\x97\x17\xfe\xc1\xe8"
        "\x49\xa7\xfd\xe0\x55\x08\x63\xe7\xcf\x52\x56\x49\x73\xc2\x59\x7f\x25"
        "\x64\xe0\x9b\xf0\xad\xb5\x4b\xca\x3c\x9d\xe3\x59\x0b\x65\xd7\xea\x7f"
        "\x4b\xd9\x7f\xf4\x9f\xf9\xd0\xa3\x0e\x66\x5d\x8f\x58\xc0\x9a\xb9\xc6"
        "\x65\x78\x9e\x73\x48\xf0\xb6\xb3\x79\xb5\x5c\xa8\x86\x67\xe1\x53\xe5"
        "\x7f\x8a\xa1\x27\xeb\x78\x27\x2f\xac\x2f\x77\x2a\xac\xf8\x55\x22\x9f"
        "\xab\x11\xaa\xf8\x36\xe2\xa0\xa2\xd0\x10\x89\x72\xeb\x3e\x00\x9f\xe0"
        "\x18\xf0\x1c\x8c\xe5\x05\x05\x45\xfb\x08\xb9\x86\x6d\x12\x4e\xf8\x8c"
        "\xee\x29\xf1\x53\x81\x39\x2a\x59\x08\x1c\x23\xd6\xb0\x61\xda\x25\x58"
        "\x57\x06\xa2\x05\x1b\x11\xd5\xe9\x51\xc1\x57\xda\xa8\x50\xcc\x5a\x3a"
        "\xa4\x74\x47\xd7\x5f\xe5\x57\xc2\xf9\x33\x9e\x2d\xfb\xbf\x98\xba\x2a"
        "\xf7\xdb\x8d\x12\xf3\x37\x4a\x77\x09\x5d\x0a\xdd\xa6\x6e\x37\x6d\x02"
        "\x3c\x58\x2d\x71\x93\x7a\x93\x8e\x55\xe3\xc5\x5a\xac\x02\xc5\xc6\xfe"
        "\xcc\x0d\x76\x61\xb8\x02\xa6\xec\x3f\x7f\x18\x74\x5d\x75\x91\x1b\xcf"
        "\x58\xbe\x3c\x8e\xab\x58\x7d\x67\x5d\xa3\xc0\x13\xaf\xf1\x0a\xd2\xdb"
        "\x11\xc8\xbc\xcb\x01\xa8\xb1\xc3\xd2\xfd\xb0\xa1\x8c\x16\x70\xe8\x17"
        "\x7a\x85\x23\xab\x68\x00\xa3\x4a\x4b\x62\x35\x92\xfc\x82\x98\xfe\x8c"
        "\x83\x5a\xf5\x6e\x0e\x3d\x1e\xfa\x86\x0e\x84\xf1\xdf\x48\x0e\x2b\xd3"
        "\x36\xa3\x68\xcb\xb0\xf1\xa9\x2d\x51\x5d\x18\x66\xf5\x3c\x1c\x52\x02"
        "\x24\xc6\x70\x9a\x92\x6a\xd5\xc0\x72\xfc\xb5\x9c\xf8\xf0\x67\xb5\x89"
        "\xc8\x6b\x8a\x9b\xc7\x9e\x12\x85\x81\xb0\x67\xbe\xeb\x6c\x73\xb2\x55"
        "\x16\x51\xc6\x20\x43\x8c\x35\xf1\x8c\x0d\x5d\x64\x25\xc1\x66\xdd\xf1"
        "\x45\x7c\xb2\x61\x1a\xa5\x72\xe2\x7e\x8e\xc6\x11\x93\xcd\x0a\x68\x3c"
        "\x7a\x4a\xd6\x41\x0f\x82\x22\x11\x3e\x5a\x78\x86\x36\x34\x7c\x23\x59"
        "\x2c\xc7\x47\xbb\x67\x21\x4c\x12\x47\x91\xbe\xb5\x52\x40\xf0\xc2\xc7"
        "\xd0\xe8\x0f\x87\x5b\x9b\xcb\x4d\xb0\x78\xbc\xe6\xc8\x4e\x58\x8f\x85"
        "\x57\x51\xe5\x89\x7d\x94\x8e\x11\xfe\x5d\x53\x27\x87\x54\xc5\x9c\xec"
        "\x2e\xba\xd9\x09\x6e\xc6\xbb\xac\x4e\xf5\xf0\x89\xcc\x84\x22\xe6\x92"
        "\xbe\xbb\x64\x69\xc0\x1f\x5b\x8c\x5f\xb7\x53\x28\x79\xc3\x2e\x6d\x2c"
        "\x82\x66\x44\x0c\xbf\x91\x54\x52\x63\xcf\xdd\xbc\x28\x9c\x7a\xb6\xfa"
        "\x69\xf6\xc8\xfa\xb4\x72\x9e\x58\x92\x8c\x60\x24\x01\x48\x04\x78\x92"
        "\x8b\xd4\x43\x18\x3c\x8c\xf4\x63\xdb\x27\x4d\x30\xe3\xb7\x21\x1e\xc5"
        "\xb0\x76\x3f\xdf\xe9\xf2\xbe\xb3\x01\x99\x15\x9d\x60\x9f\x57\x24\x73"
        "\xd8\x7a\x0f\x6f\xf1\x2f\xd7\xcd\xc4\x81\xe7\x86\x7e\xec\xa8\xf0\x0b"
        "\x0a\xa3\x5a\xfc\x52\xb3\x58\x93\xa6\xbc\xcc\xa4\xf9\x2b\x54\x7b\x99"
        "\x81\x63\x13\x51\xed\x75\x89\xca\xee\xb8\x29\xe7\xc6\xdd\x3a\xbb\x19"
        "\x15\x7f\x8d\x6c\xc4\x07\xb2\xaa\x9c\x7f\x71\x4f\x07\x93\x69\x53\x07"
        "\x5d\x7a\x39\x96\x72\x9a\xd6\xa9\xb4\xe6\x8d\x82\xc8\x06\x5c\x56\x8a"
        "\xa7\x91\x47\xee\xff\xfe\xff\x7e\x47\x56\x78\x45\x5c\x6c\x4c\xfe\x07"
        "\x36\x4a\xee\xe5\xa8\x6d\x12\x7a\xd2\xd9\x13\x3e\xeb\xae\xd2\xef\x6b"
        "\x49\xe3\x7b\xc1\x71\xc4\xca\xd2\x79\x29\xe5\xa3\x35\xdc\xe2\x18\xad"
        "\x3f\xf7\x18\xbb\xb6\xd2\xc5\x78\x45\x06\x9a\x5b\x92\xda\xf8\x50\xc5"
        "\x67\xf8\xf3\xb5\x9a\x06\x07\x79\x4f\xff\xfd\x33\x40\x78\x70\x51\x82"
        "\xf1\x33\x00\xd5\x11\x27\x4c\x29\xbf\x9d\xed\x7c\x78\xf6\x76\x75\x67"
        "\xcc\xe9\x15\x6c\x86\xe4\xf6\x0b\xed\x3a\xdd\xac\x80\x80\x65\x33\x88"
        "\x3e\x57\x50\x95\xce\x17\x6b\xfc\xa3\x30\x29\x17\x61\x9c\xe4\x52\x16"
        "\xe0\xc1\xb9\xc2\x2d\x53\xa0\x9a\x18\x2b\x46\x8b\x1c\xdc\xd5\x17\x6c"
        "\xca\xd6\x4b\x4c\x75\x46\x6a\x9b\xd2\x13\x94\x50\x6d\x3c\xe4\x92\xb1"
        "\x40\x44\x05\x95\xc2\xaf\x4d\x6b\xb5\xc6\x5f\x14\x69\x6d\x16\xb8\xdc"
        "\x76\x7f\x66\x4f\xee\x09\xa3\x35\x43\x55\x9d\xb7\xdf\x3d\x29\x36\x9c"
        "\x63\x88\x0a\xb8\x9f\x12\xc6\x07\x85\xb1\x8f\xa7\xb6\xc1\xe7\x1f\x7d"
        "\x41\x33\x27\xe5\x4e\x9e\x17\x16\xe0\x5e\xa1\x41\x61\x4b\x00\xe5\x23"
        "\x19\xb9\xca\xd9\xcf\xf9\x9a\xae\x2d\x34\x7e\xfd\xd3\x62\x88\xd8\x62"
        "\x45\x7b\x74\xbf\xa4\xf6\x8b\xb6\xf2\xc2\x12\x61\xb9\x6c\x6e\x28\x07"
        "\x7c\x50\xbe\x98\x4c\x17\x64\xf5\xbb\x64\xa9\x7a\x69\x22\xdc\xe6\x90"
        "\x72\x0c\x0b\x60\xe1\x5e\x0a\x0b\x6b\x39\x8f\x9d\x06\x57\x39\x6e\xb6"
        "\x0a\x5c\x68\xfc\x71\xd9\x82\xb5\x3e\xec\xdb\x3a\xba\x86\xa2\x03\x5c"
        "\x3a\x75\xe9\xa5\xc9\x14\x37\xeb\x39\xac\xe3\x8c\xa0\x0e\x8d\x5a\x6b"
        "\x6b\xda\xdb\x72\x44\x60\x17\x9a\x46\x59\x67\x3a\xae\x8b\x4f\xb2\x61"
        "\x04\x14\x45\x3f\x2f\x89\xad\x82\x5d\x3b\xc0\x47\xa9\x3f\x3d\x32\xdd"
        "\x89\x18\xfb\x5c\xfe\x44\x99\x48\x4c\xde\xfc\xa5\x7c\x69\x8f\xed\x8e"
        "\x24\x09\xa5\x01\x0e\x8b\xfe\x34\x4b\xfb\xbf\xae\x6f\xb2\x82\x6d\xcf"
        "\xab\x6e\xd2\xb8\x20\x81\x7b\x28\xee\xdd\xc7\x32\xb9\xd7\xb6\xdf\x85"
        "\x32\x86\x83\x9a\x42\x65\xcf\x36\x1f\xf5\xf9\x27\x0f\x29\xa0\x4e\x53"
        "\xd1\x9b\xd0\x64\x4d\x16\xd8\xc7\x2e\xe3\x34\x8c\x96\xd0\xb1\x22\x78"
        "\x6e\xca\xd1\xc9\x1e\xcc\xc6\xcb\xd1\xbe\x0c\x97\x21\xd6\x06\x23\xeb"
        "\x0e\x02\xe1\x9d\x44\xff\x36\xc8\x4f\x89\x2a\x21\x32\x8a\x04\xff\x5b"
        "\x09\x36\x97\x03\x0c\x9c\xcf\xfb\xcd\x02\x7d\x66\xf1\xd8\x8b\xdf\xcf"
        "\x16\xd8\x6c\xcb\x72\xe5\x96\xfa\x4e\x85\x59\xf2\xd5\x4d\x72\xf8\xca"
        "\x91\x1d\x49\x39\x41\x8c\x7c\x0a\xa2\x9a\xb3\x1d\x6c\x5c\xc7\x6a\x7a"
        "\xbb\xd4\xe4\x65\x54\x18\xbc\x5d\x20\x0f\xdf\x42\xfc\xcd\x35\x2e\xd4"
        "\x06\xfc\xd6\xfa\x19\x0a\x45\xd0\xe8\xa5\xf4\xa8\xb3\x86\xe5\xa5\x32"
        "\xbe\xbc\x07\x04\x7c\xe2\x29\x8a\x48\xa8\x40\xe3\x97\x35\xbf\x38",
        4096);
    syscall(__NR_write, /*fd=*/r[0], /*buf=*/0x20002a80ul, /*count=*/0x1000ul);
    break;
  case 7:
    syscall(__NR_write, /*fd=*/r[2], /*data=*/0x20002a40ul,
            /*len=*/0x156a396ul);
    break;
  }
}
int main(void)
{
  syscall(__NR_mmap, /*addr=*/0x1ffff000ul, /*len=*/0x1000ul, /*prot=*/0ul,
          /*flags=*/0x32ul, /*fd=*/-1, /*offset=*/0ul);
  syscall(__NR_mmap, /*addr=*/0x20000000ul, /*len=*/0x1000000ul, /*prot=*/7ul,
          /*flags=*/0x32ul, /*fd=*/-1, /*offset=*/0ul);
  syscall(__NR_mmap, /*addr=*/0x21000000ul, /*len=*/0x1000ul, /*prot=*/0ul,
          /*flags=*/0x32ul, /*fd=*/-1, /*offset=*/0ul);
  setup_cgroups();
  for (procid = 0; procid < 6; procid++) {
    if (fork() == 0) {
      use_temporary_dir();
      do_sandbox_none();
    }
  }
  sleep(1000000);
  return 0;
}
